AnalyticsEvent class

Constructors

AnalyticsEvent(String action, List<FeatureStateHolder> features, Map<String, Object>? other)

Properties

action → String
final
features → List<FeatureStateHolder>
final
hashCode → int
The hash code for this object.
no setterinherited
other → Map<String, Object>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited