ClientContext class

Constructors

ClientContext()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

attr(String key, String value) → ClientContext
Allows to set Custom context attribute when using rollout strategy with Custom rule. @param key Name of the Custom rule @param value Value of the Custom rule returns ClientContext
attrs(dynamic key, List<String> values) → ClientContext
Allows to set a Custom context attribute with a list of values when using rollout strategy with Custom rule. @param key Name of the Custom rule @param values Values of the Custom rule returns ClientContext
build() → void
Call this method to rebuild Context
clear() → ClientContext
Call this method to clear Context
country(StrategyAttributeCountryName countryName) → ClientContext
Allows to set Country context when using rollout strategy with Country rule. @param countryName name of the country provided as enum from StrategyAttributeCountryName returns ClientContext
device(StrategyAttributeDeviceName device) → ClientContext
Allows to set Device context when using rollout strategy with Device rule. @param device name of the device provided as enum from StrategyAttributeDeviceName returns ClientContext
generateHeader() → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
platform(StrategyAttributePlatformName platform) → ClientContext
Allows to set Platform context when using rollout strategy with Platform rule. @param platform name of the platform provided as enum from StrategyAttributePlatformName returns ClientContext
registerChangeHandler(ClientContextChangedHandler handler) → Future<Function>
sessionKey(String sessionKey) → ClientContext
For Percentage rule to work Context either needs userKey or sessionKey. If userKey is not provided, sessionKey can be used instead @param sessionKey returns ClientContext
toString() → String
A string representation of this object.
inherited
userKey(String userkey) → ClientContext
Allows to set User Key context when using rollout strategy with User Key rule. userKey can be anything that identifies your user, e.g userId, email, etc. @param userKey returns ClientContext
version(String version) → ClientContext
Allows to set Version context when using rollout strategy with Version rule. @param version Semantic version returns ClientContext

Operators

operator ==(Object other) → bool
The equality operator.
inherited