FeatureStateHolder class abstract

Constructors

FeatureStateHolder()

Properties

booleanValue → bool?
no setter
exists → bool
no setter
featureUpdateStream → Stream<FeatureStateHolder>
no setter
hashCode → int
The hash code for this object.
no setterinherited
isEnabled → bool
no setter
isSet → bool
no setter
jsonValue → dynamic
no setter
key → String?
no setter
numberValue → num?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue → String?
no setter
type → FeatureValueType?
no setter
value → dynamic
no setter
version → int?
no setter

Methods

copy() → FeatureStateHolder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited