FeatureHubConfig class

Implementers

Constructors

FeatureHubConfig(String host, List<String> _apiKeys, ClientFeatureRepository _repository, {int timeout = 360})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isConnectionDead → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeoutInSeconds → int
no setter
whenNextPollAllowed → DateTime
no setter
xFeatureHubHeader ↔ String?
getter/setter pair

Methods

checkForCacheControl(ApiResponse response) → void
decodeCacheControl(List<String> cacheControlHeader) → void
decodeResponse(ApiResponse response) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request() → Future<ClientFeatureRepository>
success(List<FeatureEnvironmentCollection> environments) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited