FeatureHubSimpleApi class

will be deprecated, please use FeatureHubConfig instead

Inheritance

Constructors

FeatureHubSimpleApi(String host, List<String> apiKeys, ClientFeatureRepository repository)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isConnectionDead → bool
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeoutInSeconds → int
no setterinherited
whenNextPollAllowed → DateTime
no setterinherited
xFeatureHubHeader ↔ String?
getter/setter pairinherited

Methods

checkForCacheControl(ApiResponse response) → void
inherited
decodeCacheControl(List<String> cacheControlHeader) → void
inherited
decodeResponse(ApiResponse response) → Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request() → Future<ClientFeatureRepository>
inherited
success(List<FeatureEnvironmentCollection> environments) → void
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited